@@ -1,7 +1,7 @@
 # Copyright 2001-2 by Roger Bivand 
 #
 
-spweights.constants <- function(listw) {
+spweights.constants <- function(listw, zero.policy=FALSE) {
 	if(class(listw) != "listw") stop(paste(deparse(substitute(listw)),
 		"is not a listw object"))
 	n <- length(listw$neighbours)
@@ -12,23 +12,31 @@ spweights.constants <- function(listw) {
 	S0 <- Szero(listw)
 	S1 <- 0
 	S2 <- 0
+	cards <- card(listw$neighbours)
 	for (i in 1:n) {
-		ij <- listw$neighbours[[i]]
-		wij <- listw$weights[[i]]
-		dm0 <- 0
-		dm1 <- 0
-		for (j in 1:length(ij)) {
-			dij <- wij[j]
-			ij.j <- ij[j]
-			ij.lkup <- which(listw$neighbours[[ij.j]] == i)
-			if (length(ij.lkup) == 1)
-				dji <- listw$weights[[ij.j]][ij.lkup]
-			else dji <- 0
-			dm0 <- dm0 + dij
-			dm1 <- dm1 + dji
-			S1 <- S1 + (dij + dji)^2
+		cond <- TRUE
+		if (zero.policy && cards[i] == 0) cond <- FALSE
+		if (cond) {
+			if (cards[i] == 0)
+				stop(paste("region", i,
+					"has no neighbours"))
+			ij <- listw$neighbours[[i]]
+			wij <- listw$weights[[i]]
+			dm0 <- 0
+			dm1 <- 0
+			for (j in 1:length(ij)) {
+				dij <- wij[j]
+				ij.j <- ij[j]
+				ij.lkup <- which(listw$neighbours[[ij.j]] == i)
+				if (length(ij.lkup) == 1)
+					dji <- listw$weights[[ij.j]][ij.lkup]
+				else dji <- 0
+				dm0 <- dm0 + dij
+				dm1 <- dm1 + dji
+				S1 <- S1 + (dij + dji)^2
+			}
+			S2 <- S2 + (dm0 + dm1)^2
 		}
-		S2 <- S2 + (dm0 + dm1)^2
 	}
 	S1 <- S1 * 0.5
 	invisible(list(n=n, n1=n1, n2=n2, n3=n3, nn=nn, S0=S0, S1=S1, S2=S2))
